@@ -1,6 +1,6 @@
 'A class and variable for Tile objects'
 #IMPORTS
-from pygame import Rect
+from pygame import Vector2, Rect
 #IMPORTS
 
 #VARIABLES
@@ -10,7 +10,7 @@ tile_size = 0
 #TILE
 class Tile:
 	'''A tile used by the Entity object to check collision
-	size can be a single number and it will be the width and the height, or it can be a tuple or list
+	size can be a single number and it will be the width and the height, or it can be a tuple/list
 	It also supports ramps (45 degrees)
 	If the width and height are not the same, ramp will be 0
 	ramp 0 = no ramp
@@ -30,17 +30,26 @@ class Tile:
 	#__INIT__
 	def __init__(self, location, size, ramp=0):
 		'Initialising a Tile object'
-		self.location = list(location)
+		self.location = Vector2(location)
 		self.size = list(size) if type(size) is list or type(size) is tuple else [size, size]
 		self.ramp = ramp if self.size[0] == self.size[1] else 0
 	#__INIT__
 
+	#__REPR__
+	def __repr__(self):
+		'''Returns a string representation of the object
+
+		Returns: str'''
+		return f'pgeng.Tile{tuple(self.location), tuple(self.size), self.ramp}'
+	#__REPR__
+
 	#RECT
 	@property
 	def rect(self):
 		'''Returns a pygame.Rect object of the Tile object
 
 		Returns: pygame.Rect'''
+		self.location = Vector2(self.location)
 		return Rect(self.location[0], self.location[1], self.size[0], self.size[1])
 	#RECT
 #TILE
\ No newline at end of file
