@@ -21,23 +21,38 @@ class ShockWave:
 	#__INIT__
 	def __init__(self, center, radius, width, colour):
 		'Initialising a Shockwave object'
-		self.center = list(center)
+		self.center = pygame.Vector2(center)
 		self.radius = radius
 		self.width = width
 		self.colour = colour
 		self.alive = True
 	#__INIT__
 
-	#UPDATE
-	def update(self, surface, radius_change, width_change, scroll=(0, 0), delta_time=1):
-		'''The move and render function of the Shockwave (it will only render it if it is still alive)
+	#__REPR__
+	def __repr__(self):
+		'''Returns a string representation of the object
+
+		Returns: str'''
+		return f'pgeng.ShockWave({tuple(self.center)})'
+	#__REPR__
+
+	#MOVE
+	def move(self, radius_change, width_change, delta_time=1):
+		'''The move function of the Shockwave
 		If the width is smaller or the same as 1, it will no longer be alive
-		scroll is position of the camera, it will render it at the center of the Shockwave minus the scroll'''
+		The radius will become bigger and the width will become smaller (by default)'''
+		self.center = pygame.Vector2(self.center)
 		self.radius += radius_change * delta_time
 		self.width -= width_change * delta_time
 		if round(self.width) <= 1:
 			self.alive = False
-		else:
-			pygame.draw.circle(surface, self.colour, [self.center[i] - scroll[i] for i in range(2)], self.radius, round(self.width))
-	#UPDATE
+	#MOVE
+
+	#RENDER
+	def render(self, surface, scroll=pygame.Vector2()):
+		'''It will only render it if it is still alive
+		scroll is position of the camera, it will render it at the center of the Shockwave minus the scroll'''
+		if self.alive:
+			pygame.draw.circle(surface, self.colour, self.center - scroll, self.radius, round(self.width))
+	#RENDER
 #SHOCKWAVE
\ No newline at end of file
